@@ -13,7 +13,7 @@
 ##############################################################################
 """Widgets Demo Implementation
 
-$Id: browser.py 76728 2007-06-17 13:35:02Z rogerineichen $
+$Id: browser.py 77034 2007-06-25 12:57:23Z srichter $
 """
 __docformat__ = "reStructuredText"
 
@@ -44,6 +44,8 @@ class AllFields(persistent.Persistent):
     bytesField = FieldProperty(interfaces.IAllFields['bytesField'])
     bytesLineField = FieldProperty(interfaces.IAllFields['bytesLineField'])
     choiceField = FieldProperty(interfaces.IAllFields['choiceField'])
+    optionalChoiceField = FieldProperty(
+        interfaces.IAllFields['optionalChoiceField'])
     dateField = FieldProperty(interfaces.IAllFields['dateField'])
     datetimeField = FieldProperty(interfaces.IAllFields['datetimeField'])
     decimalField = FieldProperty(interfaces.IAllFields['decimalField'])
